@@ -1,6 +1,7 @@
 #! /usr/bin/env python
 
 import sys
+import ast
 import traceback
 from argparse import ArgumentParser
 import onnx
@@ -64,6 +65,7 @@ NUMPY_TYPES_TO_ONNX_DTYPES = {
 def generate(
     op_type: str,
     opset: int,
+    op_name: str,
     input_variables: Optional[dict] = None,
     output_variables: Optional[dict] = None,
     attributes: Optional[dict] = None,
@@ -83,6 +85,9 @@ def generate(
         ONNX opset number.\n\
         e.g. 11
 
+    op_name: str
+        OP name.
+
     input_variables: Optional[dict]
         Specify input variables for the OP to be generated.\n\
         See below for the variables that can be specified.\n\n\
@@ -152,6 +157,7 @@ def generate(
         # non constant
         node = gs.Node(
             op=op_type,
+            name=op_name,
             attrs=attributes,
             inputs=input_gs_variables,
             outputs=output_gs_variables
@@ -176,6 +182,7 @@ def generate(
                 op_type,
                 inputs=[],
                 outputs=[constant_name],
+                name=op_name,
                 value=onnx.helper.make_tensor(
                     name='value',
                     data_type=dtype,
@@ -243,10 +250,17 @@ def main():
         required=True,
         help='ONNX opset number.'
     )
+    parser.add_argument(
+        '--op_name',
+        type=str,
+        required=True,
+        help='OP name.'
+    )
     """
     python3 onnx_operation_generator.py \
     --op_type Gemm \
     --opset 11 \
+    --op_name gemm_custom1 \
     --input_variables i1 np.float32 [1,2,3] \
     --input_variables i2 np.float32 [1,1] \
     --input_variables i3 np.float32 0 \
@@ -316,7 +330,7 @@ def main():
     """
     input_variables_tmp = None
     if args.input_variables:
-        input_variables_tmp = {input_variable[0]: [getattr(np, input_variable[1]), eval(input_variable[2])] for input_variable in args.input_variables}
+        input_variables_tmp = {input_variable[0]: [getattr(np, input_variable[1]), ast.literal_eval(input_variable[2])] for input_variable in args.input_variables}
 
     # output variables
     """
@@ -324,7 +338,7 @@ def main():
     """
     output_variables_tmp = None
     if args.output_variables:
-        output_variables_tmp = {output_variable[0]: [getattr(np, output_variable[1]), eval(output_variable[2])] for output_variable in args.output_variables}
+        output_variables_tmp = {output_variable[0]: [getattr(np, output_variable[1]), ast.literal_eval(output_variable[2])] for output_variable in args.output_variables}
 
     # attributes
     """
@@ -346,7 +360,7 @@ def main():
             # parse
             attr_name = attribute[0]
             attr_type = attribute[1]
-            attr_value = eval(attribute[2])
+            attr_value = ast.literal_eval(attribute[2])
 
             # dtype check
             if attr_type not in AVAILABLE_DTYPES:
@@ -377,6 +391,7 @@ def main():
     single_op_graph = generate(
         op_type=args.op_type,
         opset=args.opset,
+        op_name=args.op_name,
         input_variables=input_variables_tmp,
         output_variables=output_variables_tmp,
         attributes=attributes_tmp,
